==> jc-1.4.0.tar.gz: soot/dava/internal/SET/SETStatementSequenceNode.h <==
// public class soot.dava.internal.SET.SETStatementSequenceNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4d3d060182af30b5 soot_dava_internal_SET_SETNode
// @dep_class 2fab3553c8cf8069 soot_dava_internal_SET_SETStatementSequenceNode

// header file dependencies
// @dep_header soot_dava_internal_SET_SETNode

#include "soot/dava/internal/SET/SETNode.h"

#ifndef _JC_soot_dava_internal_SET_SETStatementSequenceNode_H_
#define _JC_soot_dava_internal_SET_SETStatementSequenceNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_internal_AST_ASTNode$object;
struct _jc_soot_dava_internal_SET_SETNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$sub_refs	_jc_soot_dava_internal_SET_SETStatementSequenceNode$sub_refs;
typedef struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$sub_nonrefs	_jc_soot_dava_internal_SET_SETStatementSequenceNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$refs	_jc_soot_dava_internal_SET_SETStatementSequenceNode$refs;
typedef struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$nonrefs	_jc_soot_dava_internal_SET_SETStatementSequenceNode$nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object	_jc_soot_dava_internal_SET_SETStatementSequenceNode$object;

typedef const struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$vmethods	_jc_soot_dava_internal_SET_SETStatementSequenceNode$vmethods;
typedef const struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$vtable	_jc_soot_dava_internal_SET_SETStatementSequenceNode$vtable;
typedef const struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$vtype	_jc_soot_dava_internal_SET_SETStatementSequenceNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_SET_SETStatementSequenceNode$method$_init$ffc747eec5c1567b(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *, struct _jc_soot_util_IterableSet$object *);
extern void _jc_soot_dava_internal_SET_SETStatementSequenceNode$method$_init$e1d8691554566f03(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_soot_dava_DavaBody$object *);

// Virtual methods
extern struct _jc_soot_dava_internal_AST_ASTNode$object *_jc_soot_dava_internal_SET_SETStatementSequenceNode$method$emit__5fAST$9abd6bb299fe14c5(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *);
extern struct _jc_soot_dava_internal_asg_AugmentedStmt$object *_jc_soot_dava_internal_SET_SETStatementSequenceNode$method$get__5fEntryStmt$d3b7a698292e24c9(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *);
extern struct _jc_soot_util_IterableSet$object *_jc_soot_dava_internal_SET_SETStatementSequenceNode$method$get__5fNaturalExits$93615053d2db173e(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *);
extern jboolean _jc_soot_dava_internal_SET_SETStatementSequenceNode$method$has__5fContinue$1382681b38c7a059(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *);
extern void _jc_soot_dava_internal_SET_SETStatementSequenceNode$method$insert__5fAbruptStmt$db6e27765977aec4(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *);
extern jboolean _jc_soot_dava_internal_SET_SETStatementSequenceNode$method$resolve$e7ca43c456f15a88(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_SET_SETStatementSequenceNode$method_info$emit__5fAST$9abd6bb299fe14c5;
extern _jc_method _jc_soot_dava_internal_SET_SETStatementSequenceNode$method_info$get__5fEntryStmt$d3b7a698292e24c9;
extern _jc_method _jc_soot_dava_internal_SET_SETStatementSequenceNode$method_info$get__5fNaturalExits$93615053d2db173e;
extern _jc_method _jc_soot_dava_internal_SET_SETStatementSequenceNode$method_info$has__5fContinue$1382681b38c7a059;
extern _jc_method _jc_soot_dava_internal_SET_SETStatementSequenceNode$method_info$insert__5fAbruptStmt$db6e27765977aec4;
extern _jc_method _jc_soot_dava_internal_SET_SETStatementSequenceNode$method_info$resolve$e7ca43c456f15a88;

// Virtual methods structure
struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$vmethods {
	struct _jc_soot_dava_internal_AST_ASTNode$object	*(*emit__5fAST$9abd6bb299fe14c5)(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *);
	struct _jc_soot_dava_internal_asg_AugmentedStmt$object	*(*get__5fEntryStmt$d3b7a698292e24c9)(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *);
	struct _jc_soot_util_IterableSet$object	*(*get__5fNaturalExits$93615053d2db173e)(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *);
	jboolean	(*has__5fContinue$1382681b38c7a059)(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *);
	void	(*insert__5fAbruptStmt$db6e27765977aec4)(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *);
	jboolean	(*resolve$e7ca43c456f15a88)(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
};

// Vtable
struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_SET_SETNode$vmethods	soot_dava_internal_SET_SETNode;
	_jc_soot_dava_internal_SET_SETStatementSequenceNode$vmethods	soot_dava_internal_SET_SETStatementSequenceNode;
};

// Vtype
struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_SET_SETStatementSequenceNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$sub_refs {
	struct _jc_soot_dava_DavaBody$object	*davaBody;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$refs {
    _jc_soot_dava_internal_SET_SETStatementSequenceNode$sub_refs	soot_dava_internal_SET_SETStatementSequenceNode;
    _jc_soot_dava_internal_SET_SETNode$sub_refs	soot_dava_internal_SET_SETNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$sub_nonrefs {
	jboolean	hasContinue;
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_SET_SETNode$sub_nonrefs	soot_dava_internal_SET_SETNode;
    _jc_soot_dava_internal_SET_SETStatementSequenceNode$sub_nonrefs	soot_dava_internal_SET_SETStatementSequenceNode;
};

// Object instance structure
struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object {
	_jc_soot_dava_internal_SET_SETStatementSequenceNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_SET_SETStatementSequenceNode$vtype	*vtype;
	_jc_soot_dava_internal_SET_SETStatementSequenceNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_SET_SETStatementSequenceNode$vtype _jc_soot_dava_internal_SET_SETStatementSequenceNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_SET_SETStatementSequenceNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_SET_SETStatementSequenceNode$class_object;

#endif	/* _JC_soot_dava_internal_SET_SETStatementSequenceNode_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/SET/SETStatementSequenceNode.h <==
// public class soot.dava.internal.SET.SETStatementSequenceNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4d3d060182af30b5 soot_dava_internal_SET_SETNode
// @dep_class 2fab3553c8cf8069 soot_dava_internal_SET_SETStatementSequenceNode

// header file dependencies
// @dep_header soot_dava_internal_SET_SETNode

#include "soot/dava/internal/SET/SETNode.h"

#ifndef _JC_soot_dava_internal_SET_SETStatementSequenceNode_H_
#define _JC_soot_dava_internal_SET_SETStatementSequenceNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_internal_AST_ASTNode$object;
struct _jc_soot_dava_internal_SET_SETNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$sub_refs	_jc_soot_dava_internal_SET_SETStatementSequenceNode$sub_refs;
typedef struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$sub_nonrefs	_jc_soot_dava_internal_SET_SETStatementSequenceNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$refs	_jc_soot_dava_internal_SET_SETStatementSequenceNode$refs;
typedef struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$nonrefs	_jc_soot_dava_internal_SET_SETStatementSequenceNode$nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object	_jc_soot_dava_internal_SET_SETStatementSequenceNode$object;

typedef const struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$vmethods	_jc_soot_dava_internal_SET_SETStatementSequenceNode$vmethods;
typedef const struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$vtable	_jc_soot_dava_internal_SET_SETStatementSequenceNode$vtable;
typedef const struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$vtype	_jc_soot_dava_internal_SET_SETStatementSequenceNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_SET_SETStatementSequenceNode$method$_init$ffc747eec5c1567b(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *, struct _jc_soot_util_IterableSet$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_SET_SETStatementSequenceNode$method$_init$e1d8691554566f03(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_soot_dava_DavaBody$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_dava_internal_AST_ASTNode$object *_jc_soot_dava_internal_SET_SETStatementSequenceNode$method$emit__5fAST$9abd6bb299fe14c5(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_dava_internal_asg_AugmentedStmt$object *_jc_soot_dava_internal_SET_SETStatementSequenceNode$method$get__5fEntryStmt$d3b7a698292e24c9(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_util_IterableSet$object *_jc_soot_dava_internal_SET_SETStatementSequenceNode$method$get__5fNaturalExits$93615053d2db173e(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_dava_internal_SET_SETStatementSequenceNode$method$has__5fContinue$1382681b38c7a059(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_SET_SETStatementSequenceNode$method$insert__5fAbruptStmt$db6e27765977aec4(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_dava_internal_SET_SETStatementSequenceNode$method$resolve$e7ca43c456f15a88(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_SET_SETStatementSequenceNode$method_info$emit__5fAST$9abd6bb299fe14c5;
extern _jc_method _jc_soot_dava_internal_SET_SETStatementSequenceNode$method_info$get__5fEntryStmt$d3b7a698292e24c9;
extern _jc_method _jc_soot_dava_internal_SET_SETStatementSequenceNode$method_info$get__5fNaturalExits$93615053d2db173e;
extern _jc_method _jc_soot_dava_internal_SET_SETStatementSequenceNode$method_info$has__5fContinue$1382681b38c7a059;
extern _jc_method _jc_soot_dava_internal_SET_SETStatementSequenceNode$method_info$insert__5fAbruptStmt$db6e27765977aec4;
extern _jc_method _jc_soot_dava_internal_SET_SETStatementSequenceNode$method_info$resolve$e7ca43c456f15a88;

// Virtual methods structure
struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$vmethods {
	struct _jc_soot_dava_internal_AST_ASTNode$object	*(*emit__5fAST$9abd6bb299fe14c5)(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *) _JC_JCNI_ATTR;
	struct _jc_soot_dava_internal_asg_AugmentedStmt$object	*(*get__5fEntryStmt$d3b7a698292e24c9)(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *) _JC_JCNI_ATTR;
	struct _jc_soot_util_IterableSet$object	*(*get__5fNaturalExits$93615053d2db173e)(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *) _JC_JCNI_ATTR;
	jboolean	(*has__5fContinue$1382681b38c7a059)(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *) _JC_JCNI_ATTR;
	void	(*insert__5fAbruptStmt$db6e27765977aec4)(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *, struct _jc_soot_dava_internal_javaRep_DAbruptStmt$object *) _JC_JCNI_ATTR;
	jboolean	(*resolve$e7ca43c456f15a88)(_jc_env *, struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_SET_SETNode$vmethods	soot_dava_internal_SET_SETNode;
	_jc_soot_dava_internal_SET_SETStatementSequenceNode$vmethods	soot_dava_internal_SET_SETStatementSequenceNode;
};

// Vtype
struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_SET_SETStatementSequenceNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$sub_refs {
	struct _jc_soot_dava_DavaBody$object	*davaBody;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$refs {
    _jc_soot_dava_internal_SET_SETStatementSequenceNode$sub_refs	soot_dava_internal_SET_SETStatementSequenceNode;
    _jc_soot_dava_internal_SET_SETNode$sub_refs	soot_dava_internal_SET_SETNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$sub_nonrefs {
	jboolean	hasContinue;
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_SET_SETNode$sub_nonrefs	soot_dava_internal_SET_SETNode;
    _jc_soot_dava_internal_SET_SETStatementSequenceNode$sub_nonrefs	soot_dava_internal_SET_SETStatementSequenceNode;
};

// Object instance structure
struct _jc_soot_dava_internal_SET_SETStatementSequenceNode$object {
	_jc_soot_dava_internal_SET_SETStatementSequenceNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_SET_SETStatementSequenceNode$vtype	*vtype;
	_jc_soot_dava_internal_SET_SETStatementSequenceNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_SET_SETStatementSequenceNode$vtype _jc_soot_dava_internal_SET_SETStatementSequenceNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_SET_SETStatementSequenceNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_SET_SETStatementSequenceNode$class_object;

#endif	/* _JC_soot_dava_internal_SET_SETStatementSequenceNode_H_ */
